@@ -7,7 +7,7 @@ use Scalar::Util 'blessed';
 use Number::Phone::Country qw(noexport);
 use Number::Phone::StubCountry;
 
-our $VERSION = '3.0013';
+our $VERSION = '3.1';
 
 my $NOSTUBS = 0;
 sub import {
@@ -35,44 +35,12 @@ foreach my $method (
     )
 ) {
     no strict 'refs';
-    *{__PACKAGE__."::$method"} = sub {
-        my $self = shift;
-        warn("DEPRECATION: ".__PACKAGE__."->$method should only be called as an object method\n")
-          unless(blessed($self));
-        return undef if(blessed($self) && $self->isa(__PACKAGE__));
-        $self = shift if(
-            $self eq __PACKAGE__ ||
-            substr($self, 0, 2 + length(__PACKAGE__)) eq __PACKAGE__.'::'
-        );
-        $self = __PACKAGE__->new($self)
-            unless(blessed($self) && $self->isa(__PACKAGE__));
-        return $self->$method() if($self);
-        undef;
-    }
+    *{__PACKAGE__."::$method"} = sub { undef; }
 }
 
 sub type {
-    my $parm = shift;
-    warn("DEPRECATION: ".__PACKAGE__."->type should only be called as an object method\n")
-      unless(blessed($parm));
-    my $class = __PACKAGE__;
-
-    no strict 'refs';
-
-    unless(blessed($parm) && $parm->isa(__PACKAGE__)) {
-        if(
-            $parm eq __PACKAGE__ ||
-            substr($parm, 0, 2 + length(__PACKAGE__)) eq __PACKAGE__.'::'
-        ) {
-            $class = $parm;
-            $parm = shift;
-        }
-        $parm = $class->new($parm);
-    }
-
-    my $rval = $parm ?
-        [grep { $parm->$_() } @is_methods] :
-        undef;
+    my $self = shift;
+    my $rval = [grep { $self->$_() } @is_methods];
     wantarray() ? @{$rval} : $rval;
 }
 
@@ -116,6 +84,18 @@ sub dial_to {
 
 sub intra_country_dial_to { die("don't know how\n"); }
 
+sub format_using {
+    my $self   = shift;
+    my $format = shift;
+
+    return $self->format() if($format eq 'E123');
+
+    eval "use Number::Phone::Formatter::$format";
+    die("Couldn't load format '$format': $@\n") if($@);
+    return "Number::Phone::Formatter::$format"->format($self->format());
+
+}
+
 1;
 
 =head1 NAME
@@ -148,6 +128,16 @@ so the appropriate country-specific module is loaded if available.
 If you pass in a bogus country code not recognised by
 Number::Phone::Country, the constructor will return undef.
 
+=head1 INCOMPATIBLE CHANGES
+
+Early versions of this module allowed what are now object methods
+to also be called as class methods or even as functions. This was a
+bad design decision. Use of those calling conventions was deprecated
+in version 2.0, released in January 2012, and started to emit
+warnings.
+
+All code to support those calling conventions has now been removed.
+
 =head1 COMPATIBILTY WITH libphonenumber
 
 libphonenumber is a similar project for other languages, maintained
@@ -236,11 +226,7 @@ sub _make_stub_object {
 
 =head1 METHODS
 
-All Number::Phone classes can implement the following methods, as
-object methods.  Note that in previous versions these were also required
-to work as class methods and could also work as subroutines.  That
-was a bad design decision and is deprecated.  Number::Phone will spit
-warnings if you try that now, and support will be removed in the future.
+All Number::Phone classes can implement the following object methods.
 
 The implementations in the parent class all return undef unless otherwise
 noted.
@@ -427,12 +413,27 @@ C<[qw(valid allocated geographic)]>.
 
 =item format
 
-Return a sanely formatted version of the number, complete with IDD code, eg
-for the UK number (0208) 771-2924 it would return +44 20 8771 2924.
+Return a sanely formatted E.123-compliant version of the number, complete with
+IDD code, eg for the UK number (0208) 771-2924 it would return +44 20 8771
+2924.
 
 The superclass implementation returns undef, which is nonsense, so you
 should always implement this.
 
+=item format_using
+
+If you want something different from E.123, then pass this the name of a
+L<formatter|Number::Phone::Formatters> to use.
+
+For example, if you want to get "just the digits, ma'am", use the
+L<Raw|Number::Phone::Formatter::Raw> formatter thus:
+
+  Number::Phone->new('+44 20 8771 2924')->format_using('Raw');
+
+which will return:
+
+  2087712924
+
 =item country
 
 The two letter ISO country code for the country in which the call will
